]> git.lyx.org Git - lyx.git/blobdiff - src/Row.h
Further to r26743, add CustomPars and ForcePlain layout tags to InsetLayout,
[lyx.git] / src / Row.h
index 055608bc2e0c87c04a9e94a240e38999111abc67..e5343ee50ae2cbeb81f67a2d09ce9e362115bc86 100644 (file)
--- a/src/Row.h
+++ b/src/Row.h
@@ -34,8 +34,6 @@ public:
        ///
        Row();
        ///
-       Row(pos_type pos);
-       ///
        bool changed() const { return changed_; }
        ///
        void setChanged(bool c) { changed_ = c; }
@@ -49,8 +47,8 @@ public:
        void setSelection(pos_type sel_beg, pos_type sel_end) const;
        ///
        bool selection() const;
/// Set the selection begin and end and whether the margin begin and end
/// are selected.
        void setSelectionAndMargins(DocIterator const & beg, 
                DocIterator const & end) const;
        
@@ -100,7 +98,7 @@ private:
          * \param beg
          * \param end
          */
-       bool isMarginSelected(bool margin_begin, DocIterator const & beg, 
+       bool isMarginSelected(bool left_margin, DocIterator const & beg,
                DocIterator const & end) const;
 
        /// has the Row appearance changed since last drawing?
@@ -49,8 +47,8 @@ public:
        ///
        bool selection() const;
-       /// Set the selection begin and end and whether the margin begin and end
-       /// are selected.
+       /// Set the selection begin and end and whether the left and/or right
+       /// margins are selected.
        void setSelectionAndMargins(DocIterator const & beg, 
                DocIterator const & end) const;